commit-gnue
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

gnue/geas/tools .cvsignore Makefile.am parse_lo...


From: Reinhard Mueller
Subject: gnue/geas/tools .cvsignore Makefile.am parse_lo...
Date: Mon, 23 Jul 2001 15:10:38 -0700

CVSROOT:        /cvsroot/gnue
Module name:    gnue
Changes by:     Reinhard Mueller <address@hidden>       01/07/23 15:10:38

Modified files:
        geas/tools     : .cvsignore Makefile.am parse_load_sql.py 
Added files:
        geas/tools     : geas-oidgen.c 
Removed files:
        geas/tools     : gen_uuid.c 

Log message:
        Renamed gen_uuid to geas-oidgen; cosmetic fixes.
        geas-oidgen.c can now serve as an example for parsing of command line 
options.

CVSWeb URLs:
http://savannah.gnu.org/cgi-bin/viewcvs/gnue/gnue/geas/tools/geas-oidgen.c?rev=1.1
http://savannah.gnu.org/cgi-bin/viewcvs/gnue/gnue/geas/tools/.cvsignore.diff?tr1=1.1&tr2=1.2&r1=text&r2=text
http://savannah.gnu.org/cgi-bin/viewcvs/gnue/gnue/geas/tools/Makefile.am.diff?tr1=1.8&tr2=1.9&r1=text&r2=text
http://savannah.gnu.org/cgi-bin/viewcvs/gnue/gnue/geas/tools/parse_load_sql.py.diff?tr1=1.7&tr2=1.8&r1=text&r2=text

Patches:
Index: gnue/geas/tools/.cvsignore
diff -u gnue/geas/tools/.cvsignore:1.1 gnue/geas/tools/.cvsignore:1.2
--- gnue/geas/tools/.cvsignore:1.1      Sat Jan 13 19:18:21 2001
+++ gnue/geas/tools/.cvsignore  Mon Jul 23 15:10:38 2001
@@ -1,40 +1,10 @@
-gcdverifier
-geas.spec
-geas.spec.in
+*~
+Makefile.in
+Makefile
 .deps
 .libs
 _libs
-*.a
 *.o
-*.conf
-Makefile.in
-*~
-geas-skels.*
-geas-common.*
-geas-stubs.*
-Makefile
-Makefile.in
-aclocal.m4
-config.cache
-config.guess
-config.h
-config.h.in
-config.h.win32
-config.log
-config.status
-config.sub
-configure
-configure.scan
-libtool
-ltconfig
-ltmain.sh
-stamp-h
-stamp-h.in
-stamp.h
-version.h
-config.h.in
-.exrc
-install-sh
-missing
-mkinstalldirs
-
+*.a
+gcdverifier
+geas-oidgen
Index: gnue/geas/tools/Makefile.am
diff -u gnue/geas/tools/Makefile.am:1.8 gnue/geas/tools/Makefile.am:1.9
--- gnue/geas/tools/Makefile.am:1.8     Fri Jul 20 03:33:02 2001
+++ gnue/geas/tools/Makefile.am Mon Jul 23 15:10:38 2001
@@ -1,9 +1,13 @@
-## $Id: Makefile.am,v 1.8 2001/07/20 10:33:02 reinhard Exp $
+## $Id: Makefile.am,v 1.9 2001/07/23 22:10:38 reinhard Exp $
 
-bin_PROGRAMS = gcdverifier
+bin_PROGRAMS = gcdverifier geas-oidgen
 
 INCLUDES = $(GLIB_CFLAGS) -I$(top_srcdir)/lib/classdefs
 
-LDADD = $(GLIB_LIBS) ../lib/classdefs/libclassdefs.a
-
 gcdverifier_SOURCES = gcdverifier.c
+
+gcdverifier_LDADD = $(GLIB_LIBS) ../lib/classdefs/libclassdefs.a
+
+geas_oidgen_SOURCES = geas-oidgen.c
+
+geas_oidgen_LDADD = -luuid
Index: gnue/geas/tools/parse_load_sql.py
diff -u gnue/geas/tools/parse_load_sql.py:1.7 
gnue/geas/tools/parse_load_sql.py:1.8
--- gnue/geas/tools/parse_load_sql.py:1.7       Fri Jul 20 03:33:02 2001
+++ gnue/geas/tools/parse_load_sql.py   Mon Jul 23 15:10:38 2001
@@ -26,9 +26,9 @@
 #
 # This program originally written by Neil Tiffin (address@hidden).
 #
-# $Id: parse_load_sql.py,v 1.7 2001/07/20 10:33:02 reinhard Exp $
+# $Id: parse_load_sql.py,v 1.8 2001/07/23 22:10:38 reinhard Exp $
 #
 # to use this program you will need the program "uuidgen"
 # compliled and located in the same dir as this file, then
 # type "./parse_load_sql.py [dir_name]"
 #    where dir_name = the top level dir to start search for
@@ -51,12 +51,9 @@
 #     contains a list of files to process)
 # 3 - add option to only load and not create .sql files
 # 4 - add option to only create and not load .sql files
-# 5 - figure out discrepency (if it exists) between
-#     geas uuids (32 characters) and uuid_unparse() of
-#     38 characters
-# 6 - add mysql capability and option
-# 7 - add capability to delete data before inserting
-# 8 - add capability to process a single file
+# 5 - add mysql capability and option
+# 6 - add capability to delete data before inserting
+# 7 - add capability to process a single file
 #
 
 import os
@@ -73,19 +70,15 @@
 do_all = " "
 
 def get_uuid():
-#      global my_uuids
-#      if (len(my_uuids) < 2):
-#              f = os.popen("./gen_uuid -n 25", "r")
-#              uuids = f.readlines()
-#              for uuid in uuids:
-#                      if len(uuid) and (uuid[-1] == "\n"):
-#                              my_uuids.append(uuid[:-1])
-#              f.close()
-#      return my_uuids.pop()
-       f = os.popen("uuidgen", "r")
-       uuid = f.readline()
-       f.close()
-       return uuid
+       global my_uuids
+       if (len(my_uuids) < 2):
+               f = os.popen("./geas-oidgen -n 25", "r")
+               uuids = f.readlines()
+               for uuid in uuids:
+                       if len(uuid) and (uuid[-1] == "\n"):
+                               my_uuids.append(uuid[:-1])
+               f.close()
+       return my_uuids.pop()
 
 # temp = get_uuid()
 # print my_uuids
@@ -26,9 +26,9 @@
 #
-# to use this program you will need the program "uuidgen"
+# to use this program you will need the program "geas-oidgen"
 # compliled and located in the same dir as this file, then
 # type "./parse_load_sql.py [dir_name]"



reply via email to

[Prev in Thread] Current Thread [Next in Thread]